==> gura-0.6.2-src.tar.gz: gura-0.6.2/src/module-wx/Class_wx_AuiTabArt.h <==
//----------------------------------------------------------------------------
// wxAuiTabArt
// extracted from auitabart.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_AUITABART_H__
#define __CLASS_WX_AUITABART_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxAuiTabArt
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_AuiTabArt);

//----------------------------------------------------------------------------
// Object declaration for wxAuiTabArt
//----------------------------------------------------------------------------
class Object_wx_AuiTabArt : public Object {
protected:
	wxAuiTabArt *_pEntity;
	GuraObjectObserver *_pObserver;
	bool _ownerFlag;
public:
	Gura_DeclareObjectAccessor(wx_AuiTabArt)
public:
	inline Object_wx_AuiTabArt(wxAuiTabArt *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object(Gura_UserClass(wx_AuiTabArt)),
				_pEntity(pEntity), _pObserver(pObserver), _ownerFlag(ownerFlag) {}
	inline Object_wx_AuiTabArt(Class *pClass, wxAuiTabArt *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object(pClass), _pEntity(pEntity), _pObserver(pObserver), _ownerFlag(ownerFlag) {}
	virtual ~Object_wx_AuiTabArt();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline void SetEntity(wxAuiTabArt *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) {
		if (_ownerFlag) delete _pEntity;
		_pEntity = pEntity;
		_pObserver = pObserver;
		_ownerFlag = ownerFlag;
	}
	inline void InvalidateEntity() { _pEntity = NULL, _pObserver = NULL, _ownerFlag = false; }
	inline wxAuiTabArt *GetEntity() { return _pEntity; }
	inline wxAuiTabArt *ReleaseEntity() {
		wxAuiTabArt *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline void NotifyGuraObjectDeleted() {
		if (_pObserver != NULL) _pObserver->GuraObjectDeleted();
	}
	inline bool IsInvalid(Signal sig) const {
		if (_pEntity != NULL) return false;
		SetError_InvalidWxObject(sig, "wxAuiTabArt");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif

==> gura-0.7.0-src.tar.gz: gura-0.7.0/src/module-wx/Class_wx_AuiTabArt.h <==
//----------------------------------------------------------------------------
// wxAuiTabArt
// extracted from auitabart.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_AUITABART_H__
#define __CLASS_WX_AUITABART_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxAuiTabArt
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_AuiTabArt);

//----------------------------------------------------------------------------
// Object declaration for wxAuiTabArt
//----------------------------------------------------------------------------
class Object_wx_AuiTabArt : public Object {
protected:
	wxAuiTabArt *_pEntity;
	GuraObjectObserver *_pObserver;
	bool _ownerFlag;
public:
	Gura_DeclareObjectAccessor(wx_AuiTabArt)
public:
	inline Object_wx_AuiTabArt(wxAuiTabArt *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object(Gura_UserClass(wx_AuiTabArt)),
				_pEntity(pEntity), _pObserver(pObserver), _ownerFlag(ownerFlag) {}
	inline Object_wx_AuiTabArt(Class *pClass, wxAuiTabArt *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object(pClass), _pEntity(pEntity), _pObserver(pObserver), _ownerFlag(ownerFlag) {}
	virtual ~Object_wx_AuiTabArt();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline void SetEntity(wxAuiTabArt *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) {
		if (_ownerFlag) delete _pEntity;
		_pEntity = pEntity;
		_pObserver = pObserver;
		_ownerFlag = ownerFlag;
	}
	inline void InvalidateEntity() { _pEntity = nullptr, _pObserver = nullptr, _ownerFlag = false; }
	inline wxAuiTabArt *GetEntity() { return _pEntity; }
	inline wxAuiTabArt *ReleaseEntity() {
		wxAuiTabArt *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline void NotifyGuraObjectDeleted() {
		if (_pObserver != nullptr) _pObserver->GuraObjectDeleted();
	}
	inline bool IsInvalid(Signal &sig) const {
		if (_pEntity != nullptr) return false;
		SetError_InvalidWxObject(sig, "wxAuiTabArt");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif
